"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified job. You can only cancel a job before its JobState value changes to PreparingAppliance. Requesting the ListJobs or DescribeJob action returns a job's JobState as part of the response element data returned.

    Args:
        job_id(str): The 39-character job ID for the job that you want to cancel, for example JID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.init.cancel(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.init.cancel job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="cancel_job",
        op_kwargs={"JobId": job_id},
    )


async def create(
    hub,
    ctx,
    job_type: str = None,
    resources: Dict = None,
    on_device_service_configuration: Dict = None,
    description: str = None,
    address_id: str = None,
    kms_key_arn: str = None,
    role_arn: str = None,
    snowball_capacity_preference: str = None,
    shipping_option: str = None,
    notification: Dict = None,
    cluster_id: str = None,
    snowball_type: str = None,
    forwarding_address_id: str = None,
    tax_documents: Dict = None,
    device_configuration: Dict = None,
    remote_management: str = None,
    long_term_pricing_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a job to import or export data between Amazon S3 and your on-premises data center. Your AWS account must have the right trust policies and permissions in place to create a job for a Snow device. If you're creating a job for a node in a cluster, you only need to provide the clusterId value; the other job attributes are inherited from the cluster.   Only the Snowball; Edge device type is supported when ordering clustered jobs. The device capacity is optional. Availability of device types differ by AWS Region. For more information about Region availability, see AWS Regional Services.    AWS Snow Family device types and their capacities.    Snow Family device type: SNC1_SSD    Capacity: T14   Description: Snowcone       Snow Family device type: SNC1_HDD    Capacity: T8   Description: Snowcone       Device type: EDGE_S    Capacity: T98   Description: Snowball Edge Storage Optimized for data transfer only       Device type: EDGE_CG    Capacity: T42   Description: Snowball Edge Compute Optimized with GPU      Device type: EDGE_C    Capacity: T42   Description: Snowball Edge Compute Optimized without GPU      Device type: EDGE    Capacity: T100   Description: Snowball Edge Storage Optimized with EC2 Compute      Device type: STANDARD    Capacity: T50   Description: Original Snowball device  This device is only available in the Ningxia, Beijing, and Singapore AWS Regions.        Device type: STANDARD    Capacity: T80   Description: Original Snowball device  This device is only available in the Ningxia, Beijing, and Singapore AWS Regions.

    Args:
        job_type(str, optional): Defines the type of job that you're creating. . Defaults to None.
        resources(Dict, optional): Defines the Amazon S3 buckets associated with this job. With IMPORT jobs, you specify the bucket or buckets that your transferred data will be imported into. With EXPORT jobs, you specify the bucket or buckets that your transferred data will be exported from. Optionally, you can also specify a KeyRange value. If you choose to export a range, you define the length of the range by providing either an inclusive BeginMarker value, an inclusive EndMarker value, or both. Ranges are UTF-8 binary sorted. Defaults to None.
        on_device_service_configuration(Dict, optional): Specifies the service or services on the Snow Family device that your transferred data will be exported from or imported into. AWS Snow Family supports Amazon S3 and NFS (Network File System). Defaults to None.
        description(str, optional): Defines an optional description of this specific job, for example Important Photos 2016-08-11. Defaults to None.
        address_id(str, optional): The ID for the address that you want the Snow device shipped to. Defaults to None.
        kms_key_arn(str, optional): The KmsKeyARN that you want to associate with this job. KmsKeyARNs are created using the CreateKey AWS Key Management Service (KMS) API action. Defaults to None.
        role_arn(str, optional): The RoleARN that you want to associate with this job. RoleArns are created using the CreateRole AWS Identity and Access Management (IAM) API action. Defaults to None.
        snowball_capacity_preference(str, optional): If your job is being created in one of the US regions, you have the option of specifying what size Snow device you'd like for this job. In all other regions, Snowballs come with 80 TB in storage capacity. For more information, see "https://docs.aws.amazon.com/snowball/latest/snowcone-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide or "https://docs.aws.amazon.com/snowball/latest/developer-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide. Defaults to None.
        shipping_option(str, optional): The shipping speed for this job. This speed doesn't dictate how soon you'll get the Snow device, rather it represents how quickly the Snow device moves to its destination while in transit. Regional shipping speeds are as follows:   In Australia, you have access to express shipping. Typically, Snow devices shipped express are delivered in about a day.   In the European Union (EU), you have access to express shipping. Typically, Snow devices shipped express are delivered in about a day. In addition, most countries in the EU have access to standard shipping, which typically takes less than a week, one way.   In India, Snow devices are delivered in one to seven days.   In the US, you have access to one-day shipping and two-day shipping.  . Defaults to None.
        notification(Dict, optional): Defines the Amazon Simple Notification Service (Amazon SNS) notification settings for this job. Defaults to None.
        cluster_id(str, optional): The ID of a cluster. If you're creating a job for a node in a cluster, you need to provide only this clusterId value. The other job attributes are inherited from the cluster. Defaults to None.
        snowball_type(str, optional): The type of AWS Snow Family device to use for this job.   For cluster jobs, AWS Snow Family currently supports only the EDGE device type.  The type of AWS Snow device to use for this job. Currently, the only supported device type for cluster jobs is EDGE. For more information, see Snowball Edge Device Options in the Snowball Edge Developer Guide. For more information, see "https://docs.aws.amazon.com/snowball/latest/snowcone-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide or "https://docs.aws.amazon.com/snowball/latest/developer-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide. Defaults to None.
        forwarding_address_id(str, optional): The forwarding address ID for a job. This field is not supported in most Regions. Defaults to None.
        tax_documents(Dict, optional): The tax documents required in your AWS Region. Defaults to None.
        device_configuration(Dict, optional): Defines the device configuration for an AWS Snowcone job. For more information, see "https://docs.aws.amazon.com/snowball/latest/snowcone-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide or "https://docs.aws.amazon.com/snowball/latest/developer-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide. Defaults to None.
        remote_management(str, optional): Allows you to securely operate and manage Snowcone devices remotely from outside of your internal network. When set to INSTALLED_AUTOSTART, remote management will automatically be available when the device arrives at your location. Otherwise, you need to use the Snowball Client to manage the device. Defaults to None.
        long_term_pricing_id(str, optional): The ID of the long-term pricing type for the device. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="create_job",
        op_kwargs={
            "JobType": job_type,
            "Resources": resources,
            "OnDeviceServiceConfiguration": on_device_service_configuration,
            "Description": description,
            "AddressId": address_id,
            "KmsKeyARN": kms_key_arn,
            "RoleARN": role_arn,
            "SnowballCapacityPreference": snowball_capacity_preference,
            "ShippingOption": shipping_option,
            "Notification": notification,
            "ClusterId": cluster_id,
            "SnowballType": snowball_type,
            "ForwardingAddressId": forwarding_address_id,
            "TaxDocuments": tax_documents,
            "DeviceConfiguration": device_configuration,
            "RemoteManagement": remote_management,
            "LongTermPricingId": long_term_pricing_id,
        },
    )


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific job including shipping information, job status, and other important metadata.

    Args:
        job_id(str): The automatically generated ID for a job, for example JID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.init.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.init.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="describe_job",
        op_kwargs={"JobId": job_id},
    )


async def update(
    hub,
    ctx,
    job_id: str,
    role_arn: str = None,
    notification: Dict = None,
    resources: Dict = None,
    on_device_service_configuration: Dict = None,
    address_id: str = None,
    shipping_option: str = None,
    description: str = None,
    snowball_capacity_preference: str = None,
    forwarding_address_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    While a job's JobState value is New, you can update some of the information associated with a job. Once the job changes to a different job state, usually within 60 minutes of the job being created, this action is no longer available.

    Args:
        job_id(str): The job ID of the job that you want to update, for example JID123e4567-e89b-12d3-a456-426655440000.
        role_arn(str, optional): The new role Amazon Resource Name (ARN) that you want to associate with this job. To create a role ARN, use the CreateRoleAWS Identity and Access Management (IAM) API action. Defaults to None.
        notification(Dict, optional): The new or updated Notification object. Defaults to None.
        resources(Dict, optional): The updated JobResource object, or the updated JobResource object. . Defaults to None.
        on_device_service_configuration(Dict, optional): Specifies the service or services on the Snow Family device that your transferred data will be exported from or imported into. AWS Snow Family supports Amazon S3 and NFS (Network File System). Defaults to None.
        address_id(str, optional): The ID of the updated Address object. Defaults to None.
        shipping_option(str, optional): The updated shipping option value of this job's ShippingDetails object. Defaults to None.
        description(str, optional): The updated description of this job's JobMetadata object. Defaults to None.
        snowball_capacity_preference(str, optional): The updated SnowballCapacityPreference of this job's JobMetadata object. The 50 TB Snowballs are only available in the US regions. For more information, see "https://docs.aws.amazon.com/snowball/latest/snowcone-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide or "https://docs.aws.amazon.com/snowball/latest/developer-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide. Defaults to None.
        forwarding_address_id(str, optional): The updated ID for the forwarding address for a job. This field is not supported in most regions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.init.update(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.init.update job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="update_job",
        op_kwargs={
            "JobId": job_id,
            "RoleARN": role_arn,
            "Notification": notification,
            "Resources": resources,
            "OnDeviceServiceConfiguration": on_device_service_configuration,
            "AddressId": address_id,
            "ShippingOption": shipping_option,
            "Description": description,
            "SnowballCapacityPreference": snowball_capacity_preference,
            "ForwardingAddressId": forwarding_address_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def allocate(hub, ctx, static_ip_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Allocates a static IP address.

    Args:
        static_ip_name(str): The name of the static IP address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.static_ip.allocate(ctx, static_ip_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.static_ip.allocate static_ip_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="allocate_static_ip",
        op_kwargs={"staticIpName": static_ip_name},
    )


async def attach(hub, ctx, static_ip_name: str, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a static IP address to a specific Amazon Lightsail instance.

    Args:
        static_ip_name(str): The name of the static IP.
        instance_name(str): The instance name to which you want to attach the static IP address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.static_ip.attach(
                ctx, static_ip_name=value, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.static_ip.attach static_ip_name=value, instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="attach_static_ip",
        op_kwargs={"staticIpName": static_ip_name, "instanceName": instance_name},
    )


async def detach(hub, ctx, static_ip_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Detaches a static IP from the Amazon Lightsail instance to which it is attached.

    Args:
        static_ip_name(str): The name of the static IP to detach from the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.static_ip.detach(ctx, static_ip_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.static_ip.detach static_ip_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="detach_static_ip",
        op_kwargs={"staticIpName": static_ip_name},
    )


async def get(hub, ctx, static_ip_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about an Amazon Lightsail static IP.

    Args:
        static_ip_name(str): The name of the static IP in Lightsail.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.static_ip.get(ctx, static_ip_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.static_ip.get static_ip_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_static_ip",
        op_kwargs={"staticIpName": static_ip_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all static IPs in the user's account.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetStaticIps request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.static_ip.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.static_ip.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_static_ips",
        op_kwargs={"pageToken": page_token},
    )


async def release(hub, ctx, static_ip_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific static IP from your account.

    Args:
        static_ip_name(str): The name of the static IP to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.static_ip.release(ctx, static_ip_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.static_ip.release static_ip_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="release_static_ip",
        op_kwargs={"staticIpName": static_ip_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, variable_entries: List, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a batch of variables.

    Args:
        variable_entries(List): The list of variables for the batch create variable request.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.create_variable.batch(ctx, variable_entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.create_variable.batch variable_entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="batch_create_variable",
        op_kwargs={"variableEntries": variable_entries, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, report_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified report definition in AWS Application Cost Profiler. This stops the report from being generated.

    Args:
        report_id(str): Required. ID of the report to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.applicationcostprofiler.report_definition.delete(
                ctx, report_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.applicationcostprofiler.report_definition.delete report_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="applicationcostprofiler",
        operation="delete_report_definition",
        op_kwargs={"reportId": report_id},
    )


async def get(hub, ctx, report_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the definition of a report already configured in AWS Application Cost Profiler.

    Args:
        report_id(str): ID of the report to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.applicationcostprofiler.report_definition.get(
                ctx, report_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.applicationcostprofiler.report_definition.get report_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="applicationcostprofiler",
        operation="get_report_definition",
        op_kwargs={"reportId": report_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all reports and their configurations for your AWS account. The maximum number of reports is one.

    Args:
        next_token(str, optional): The token value from a previous call to access the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.applicationcostprofiler.report_definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.applicationcostprofiler.report_definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="applicationcostprofiler",
        operation="list_report_definitions",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def put(
    hub,
    ctx,
    report_id: str,
    report_description: str,
    report_frequency: str,
    format_: str,
    destination_s3_location: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the report definition for a report in Application Cost Profiler.

    Args:
        report_id(str): Required. ID of the report. You can choose any valid string matching the pattern for the ID.
        report_description(str): Required. Description of the report.
        report_frequency(str): Required. The cadence to generate the report.
        format_(str): Required. The format to use for the generated report.
        destination_s3_location(Dict): Required. Amazon Simple Storage Service (Amazon S3) location where Application Cost Profiler uploads the report.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.applicationcostprofiler.report_definition.put(
                ctx,
                report_id=value,
                report_description=value,
                report_frequency=value,
                format_=value,
                destination_s3_location=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.applicationcostprofiler.report_definition.put report_id=value, report_description=value, report_frequency=value, format_=value, destination_s3_location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="applicationcostprofiler",
        operation="put_report_definition",
        op_kwargs={
            "reportId": report_id,
            "reportDescription": report_description,
            "reportFrequency": report_frequency,
            "format": format_,
            "destinationS3Location": destination_s3_location,
        },
    )


async def update(
    hub,
    ctx,
    report_id: str,
    report_description: str,
    report_frequency: str,
    format_: str,
    destination_s3_location: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates existing report in AWS Application Cost Profiler.

    Args:
        report_id(str): Required. ID of the report to update.
        report_description(str): Required. Description of the report.
        report_frequency(str): Required. The cadence to generate the report.
        format_(str): Required. The format to use for the generated report.
        destination_s3_location(Dict): Required. Amazon Simple Storage Service (Amazon S3) location where Application Cost Profiler uploads the report.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.applicationcostprofiler.report_definition.update(
                ctx,
                report_id=value,
                report_description=value,
                report_frequency=value,
                format_=value,
                destination_s3_location=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.applicationcostprofiler.report_definition.update report_id=value, report_description=value, report_frequency=value, format_=value, destination_s3_location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="applicationcostprofiler",
        operation="update_report_definition",
        op_kwargs={
            "reportId": report_id,
            "reportDescription": report_description,
            "reportFrequency": report_frequency,
            "format": format_,
            "destinationS3Location": destination_s3_location,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "resource_type"


async def get(hub, ctx, resource_types: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the number of resources that are compliant and the number that are noncompliant. You can specify one or more resource types to get these numbers for each resource type. The maximum number returned is 100.

    Args:
        resource_types(List, optional): Specify one or more resource types to get the number of resources that are compliant and the number that are noncompliant for each resource type. For this request, you can specify an AWS resource type such as AWS::EC2::Instance. You can specify that the resource type is an AWS account by specifying AWS::::Account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.compliance.summary_by.resource_type_.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.compliance.summary_by.resource_type.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_compliance_summary_by_resource_type",
        op_kwargs={"ResourceTypes": resource_types},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, certificate_authority_arn: str, certificate_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a certificate from your private CA or one that has been shared with you. The ARN of the certificate is returned when you call the IssueCertificate action. You must specify both the ARN of your private CA and the ARN of the issued certificate when calling the GetCertificate action. You can retrieve the certificate if it is in the ISSUED state. You can call the CreateCertificateAuthorityAuditReport action to create a report that contains information about all of the certificates issued and revoked by your private CA.

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) that was returned when you called CreateCertificateAuthority. This must be of the form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 . .
        certificate_arn(str): The ARN of the issued certificate. The ARN contains the certificate serial number and must be in the following form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012/certificate/286535153982981100925020015808220737245  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.init.get(
                ctx, certificate_authority_arn=value, certificate_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.init.get certificate_authority_arn=value, certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="get_certificate",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "CertificateArn": certificate_arn,
        },
    )


async def issue(
    hub,
    ctx,
    certificate_authority_arn: str,
    csr: bytes,
    signing_algorithm: str,
    validity: Dict,
    api_passthrough: Dict = None,
    template_arn: str = None,
    validity_not_before: Dict = None,
    idempotency_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uses your private certificate authority (CA), or one that has been shared with you, to issue a client certificate. This action returns the Amazon Resource Name (ARN) of the certificate. You can retrieve the certificate by calling the GetCertificate action and specifying the ARN.   You cannot use the ACM ListCertificateAuthorities action to retrieve the ARNs of the certificates that you issue by using ACM Private CA.

    Args:
        api_passthrough(Dict, optional): Specifies X.509 certificate information to be included in the issued certificate. An APIPassthrough or APICSRPassthrough template variant must be selected, or else this parameter is ignored. For more information about using these templates, see Understanding Certificate Templates. If conflicting or duplicate certificate information is supplied during certificate issuance, ACM Private CA applies order of operation rules to determine what information is used. Defaults to None.
        certificate_authority_arn(str): The Amazon Resource Name (ARN) that was returned when you called CreateCertificateAuthority. This must be of the form:  arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012  .
        csr(bytes): The certificate signing request (CSR) for the certificate you want to issue. As an example, you can use the following OpenSSL command to create the CSR and a 2048 bit RSA private key.   openssl req -new -newkey rsa:2048 -days 365 -keyout private/test_cert_priv_key.pem -out csr/test_cert_.csr  If you have a configuration file, you can then use the following OpenSSL command. The usr_cert block in the configuration file contains your X509 version 3 extensions.   openssl req -new -config openssl_rsa.cnf -extensions usr_cert -newkey rsa:2048 -days -365 -keyout private/test_cert_priv_key.pem -out csr/test_cert_.csr  Note: A CSR must provide either a subject name or a subject alternative name or the request will be rejected. .
        signing_algorithm(str): The name of the algorithm that will be used to sign the certificate to be issued.  This parameter should not be confused with the SigningAlgorithm parameter used to sign a CSR in the CreateCertificateAuthority action.
        template_arn(str, optional): Specifies a custom configuration template to use when issuing a certificate. If this parameter is not provided, ACM Private CA defaults to the EndEntityCertificate/V1 template. For CA certificates, you should choose the shortest path length that meets your needs. The path length is indicated by the PathLenN portion of the ARN, where N is the CA depth. Note: The CA depth configured on a subordinate CA certificate must not exceed the limit set by its parents in the CA hierarchy. For a list of TemplateArn values supported by ACM Private CA, see Understanding Certificate Templates. Defaults to None.
        validity(Dict): Information describing the end of the validity period of the certificate. This parameter sets the “Not After” date for the certificate. Certificate validity is the period of time during which a certificate is valid. Validity can be expressed as an explicit date and time when the certificate expires, or as a span of time after issuance, stated in days, months, or years. For more information, see Validity in RFC 5280.  This value is unaffected when ValidityNotBefore is also specified. For example, if Validity is set to 20 days in the future, the certificate will expire 20 days from issuance time regardless of the ValidityNotBefore value. The end of the validity period configured on a certificate must not exceed the limit set on its parents in the CA hierarchy.
        validity_not_before(Dict, optional): Information describing the start of the validity period of the certificate. This parameter sets the “Not Before" date for the certificate. By default, when issuing a certificate, ACM Private CA sets the "Not Before" date to the issuance time minus 60 minutes. This compensates for clock inconsistencies across computer systems. The ValidityNotBefore parameter can be used to customize the “Not Before” value.  Unlike the Validity parameter, the ValidityNotBefore parameter is optional. The ValidityNotBefore value is expressed as an explicit date and time, using the Validity type value ABSOLUTE. For more information, see Validity in this API reference and Validity in RFC 5280. Defaults to None.
        idempotency_token(str, optional): Alphanumeric string that can be used to distinguish between calls to the IssueCertificate action. Idempotency tokens for IssueCertificate time out after one minute. Therefore, if you call IssueCertificate multiple times with the same idempotency token within one minute, ACM Private CA recognizes that you are requesting only one certificate and will issue only one. If you change the idempotency token for each call, PCA recognizes that you are requesting multiple certificates. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.init.issue(
                ctx,
                certificate_authority_arn=value,
                csr=value,
                signing_algorithm=value,
                validity=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.init.issue certificate_authority_arn=value, csr=value, signing_algorithm=value, validity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="issue_certificate",
        op_kwargs={
            "ApiPassthrough": api_passthrough,
            "CertificateAuthorityArn": certificate_authority_arn,
            "Csr": csr,
            "SigningAlgorithm": signing_algorithm,
            "TemplateArn": template_arn,
            "Validity": validity,
            "ValidityNotBefore": validity_not_before,
            "IdempotencyToken": idempotency_token,
        },
    )


async def revoke(
    hub,
    ctx,
    certificate_authority_arn: str,
    certificate_serial: str,
    revocation_reason: str,
) -> None:
    r"""
    **Autogenerated function**

    Revokes a certificate that was issued inside ACM Private CA. If you enable a certificate revocation list (CRL) when you create or update your private CA, information about the revoked certificates will be included in the CRL. ACM Private CA writes the CRL to an S3 bucket that you specify. A CRL is typically updated approximately 30 minutes after a certificate is revoked. If for any reason the CRL update fails, ACM Private CA attempts makes further attempts every 15 minutes. With Amazon CloudWatch, you can create alarms for the metrics CRLGenerated and MisconfiguredCRLBucket. For more information, see Supported CloudWatch Metrics.  Both PCA and the IAM principal must have permission to write to the S3 bucket that you specify. If the IAM principal making the call does not have permission to write to the bucket, then an exception is thrown. For more information, see Configure Access to ACM Private CA.  ACM Private CA also writes revocation information to the audit report. For more information, see CreateCertificateAuthorityAuditReport.  You cannot revoke a root CA self-signed certificate.

    Args:
        certificate_authority_arn(str): Amazon Resource Name (ARN) of the private CA that issued the certificate to be revoked. This must be of the form:  arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012  .
        certificate_serial(str): Serial number of the certificate to be revoked. This must be in hexadecimal format. You can retrieve the serial number by calling GetCertificate with the Amazon Resource Name (ARN) of the certificate you want and the ARN of your private CA. The GetCertificate action retrieves the certificate in the PEM format. You can use the following OpenSSL command to list the certificate in text format and copy the hexadecimal serial number.   openssl x509 -in file_path -text -noout  You can also copy the serial number from the console or use the DescribeCertificate action in the AWS Certificate Manager API Reference. .
        revocation_reason(str): Specifies why you revoked the certificate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.init.revoke(
                ctx,
                certificate_authority_arn=value,
                certificate_serial=value,
                revocation_reason=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.init.revoke certificate_authority_arn=value, certificate_serial=value, revocation_reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="revoke_certificate",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "CertificateSerial": certificate_serial,
            "RevocationReason": revocation_reason,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def describe(hub, ctx, layer_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes load-based auto scaling configurations for specified layers.  You must specify at least one of the parameters.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        layer_ids(List): An array of layer IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.load_based_auto_scaling.describe(ctx, layer_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.load_based_auto_scaling.describe layer_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_load_based_auto_scaling",
        op_kwargs={"LayerIds": layer_ids},
    )


async def set_(
    hub,
    ctx,
    layer_id: str,
    enable: bool = None,
    up_scaling: Dict = None,
    down_scaling: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Specify the load-based auto scaling configuration for a specified layer. For more information, see Managing Load with Time-based and Load-based Instances.  To use load-based auto scaling, you must create a set of load-based auto scaling instances. Load-based auto scaling operates only on the instances from that set, so you must ensure that you have created enough instances to handle the maximum anticipated load.   Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        layer_id(str): The layer ID.
        enable(bool, optional): Enables load-based auto scaling for the layer. Defaults to None.
        up_scaling(Dict, optional): An AutoScalingThresholds object with the upscaling threshold configuration. If the load exceeds these thresholds for a specified amount of time, AWS OpsWorks Stacks starts a specified number of instances. Defaults to None.
        down_scaling(Dict, optional): An AutoScalingThresholds object with the downscaling threshold configuration. If the load falls below these thresholds for a specified amount of time, AWS OpsWorks Stacks stops a specified number of instances. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.load_based_auto_scaling.set(ctx, layer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.load_based_auto_scaling.set layer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="set_load_based_auto_scaling",
        op_kwargs={
            "LayerId": layer_id,
            "Enable": enable,
            "UpScaling": up_scaling,
            "DownScaling": down_scaling,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    frequency: str,
    target_check_names: List,
    scheduled_audit_name: str,
    day_of_month: str = None,
    day_of_week: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a scheduled audit that is run at a specified time interval.

    Args:
        frequency(str): How often the scheduled audit takes place, either DAILY, WEEKLY, BIWEEKLY or MONTHLY. The start time of each audit is determined by the system.
        day_of_month(str, optional): The day of the month on which the scheduled audit takes place. This can be "1" through "31" or "LAST". This field is required if the "frequency" parameter is set to MONTHLY. If days 29 to 31 are specified, and the month doesn't have that many days, the audit takes place on the LAST day of the month. Defaults to None.
        day_of_week(str, optional): The day of the week on which the scheduled audit takes place, either SUN, MON, TUE, WED, THU, FRI, or SAT. This field is required if the frequency parameter is set to WEEKLY or BIWEEKLY. Defaults to None.
        target_check_names(List): Which checks are performed during the scheduled audit. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.).
        scheduled_audit_name(str): The name you want to give to the scheduled audit. (Max. 128 chars).
        tags(List, optional): Metadata that can be used to manage the scheduled audit. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.scheduled_audit.create(
                ctx, frequency=value, target_check_names=value, scheduled_audit_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.scheduled_audit.create frequency=value, target_check_names=value, scheduled_audit_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_scheduled_audit",
        op_kwargs={
            "frequency": frequency,
            "dayOfMonth": day_of_month,
            "dayOfWeek": day_of_week,
            "targetCheckNames": target_check_names,
            "scheduledAuditName": scheduled_audit_name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, scheduled_audit_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a scheduled audit.

    Args:
        scheduled_audit_name(str): The name of the scheduled audit you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.scheduled_audit.delete(ctx, scheduled_audit_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.scheduled_audit.delete scheduled_audit_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_scheduled_audit",
        op_kwargs={"scheduledAuditName": scheduled_audit_name},
    )


async def describe(hub, ctx, scheduled_audit_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a scheduled audit.

    Args:
        scheduled_audit_name(str): The name of the scheduled audit whose information you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.scheduled_audit.describe(ctx, scheduled_audit_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.scheduled_audit.describe scheduled_audit_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_scheduled_audit",
        op_kwargs={"scheduledAuditName": scheduled_audit_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of your scheduled audits.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.scheduled_audit.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.scheduled_audit.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_scheduled_audits",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    scheduled_audit_name: str,
    frequency: str = None,
    day_of_month: str = None,
    day_of_week: str = None,
    target_check_names: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a scheduled audit, including which checks are performed and how often the audit takes place.

    Args:
        frequency(str, optional): How often the scheduled audit takes place, either DAILY, WEEKLY, BIWEEKLY, or MONTHLY. The start time of each audit is determined by the system. Defaults to None.
        day_of_month(str, optional): The day of the month on which the scheduled audit takes place. This can be 1 through 31 or LAST. This field is required if the frequency parameter is set to MONTHLY. If days 29-31 are specified, and the month does not have that many days, the audit takes place on the "LAST" day of the month. Defaults to None.
        day_of_week(str, optional): The day of the week on which the scheduled audit takes place. This can be one of SUN, MON, TUE, WED, THU, FRI, or SAT. This field is required if the "frequency" parameter is set to WEEKLY or BIWEEKLY. Defaults to None.
        target_check_names(List, optional): Which checks are performed during the scheduled audit. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.). Defaults to None.
        scheduled_audit_name(str): The name of the scheduled audit. (Max. 128 chars).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.scheduled_audit.update(ctx, scheduled_audit_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.scheduled_audit.update scheduled_audit_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_scheduled_audit",
        op_kwargs={
            "frequency": frequency,
            "dayOfMonth": day_of_month,
            "dayOfWeek": day_of_week,
            "targetCheckNames": target_check_names,
            "scheduledAuditName": scheduled_audit_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_cluster_snapshot_identifier: str,
    target_db_cluster_snapshot_identifier: str,
    kms_key_id: str = None,
    pre_signed_url: str = None,
    copy_tags: bool = None,
    tags: List = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies a snapshot of a DB cluster. To copy a DB cluster snapshot from a shared manual DB cluster snapshot, SourceDBClusterSnapshotIdentifier must be the Amazon Resource Name (ARN) of the shared DB cluster snapshot.

    Args:
        source_db_cluster_snapshot_identifier(str): The identifier of the DB cluster snapshot to copy. This parameter is not case-sensitive. Constraints:   Must specify a valid system snapshot in the "available" state.   Specify a valid DB snapshot identifier.   Example: my-cluster-snapshot1 .
        target_db_cluster_snapshot_identifier(str): The identifier of the new DB cluster snapshot to create from the source DB cluster snapshot. This parameter is not case-sensitive. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: my-cluster-snapshot2 .
        kms_key_id(str, optional): The Amazon Amazon KMS key ID for an encrypted DB cluster snapshot. The KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key alias for the KMS encryption key. If you copy an encrypted DB cluster snapshot from your Amazon account, you can specify a value for KmsKeyId to encrypt the copy with a new KMS encryption key. If you don't specify a value for KmsKeyId, then the copy of the DB cluster snapshot is encrypted with the same KMS key as the source DB cluster snapshot. If you copy an encrypted DB cluster snapshot that is shared from another Amazon account, then you must specify a value for KmsKeyId.  KMS encryption keys are specific to the Amazon Region that they are created in, and you can't use encryption keys from one Amazon Region in another Amazon Region. You cannot encrypt an unencrypted DB cluster snapshot when you copy it. If you try to copy an unencrypted DB cluster snapshot and specify a value for the KmsKeyId parameter, an error is returned. Defaults to None.
        pre_signed_url(str, optional): Not currently supported. Defaults to None.
        copy_tags(bool, optional): True to copy all tags from the source DB cluster snapshot to the target DB cluster snapshot, and otherwise false. The default is false. Defaults to None.
        tags(List, optional): The tags to assign to the new DB cluster snapshot copy. Defaults to None.
        source_region(str, optional): The ID of the region that contains the snapshot to be copied. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.snapshot.init.copy(
                ctx,
                source_db_cluster_snapshot_identifier=value,
                target_db_cluster_snapshot_identifier=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.snapshot.init.copy source_db_cluster_snapshot_identifier=value, target_db_cluster_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="copy_db_cluster_snapshot",
        op_kwargs={
            "SourceDBClusterSnapshotIdentifier": source_db_cluster_snapshot_identifier,
            "TargetDBClusterSnapshotIdentifier": target_db_cluster_snapshot_identifier,
            "KmsKeyId": kms_key_id,
            "PreSignedUrl": pre_signed_url,
            "CopyTags": copy_tags,
            "Tags": tags,
            "SourceRegion": source_region,
        },
    )


async def create(
    hub,
    ctx,
    db_cluster_snapshot_identifier: str,
    db_cluster_identifier: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a DB cluster.

    Args:
        db_cluster_snapshot_identifier(str): The identifier of the DB cluster snapshot. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: my-cluster1-snapshot1 .
        db_cluster_identifier(str): The identifier of the DB cluster to create a snapshot for. This parameter is not case-sensitive. Constraints:   Must match the identifier of an existing DBCluster.   Example: my-cluster1 .
        tags(List, optional): The tags to be assigned to the DB cluster snapshot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.snapshot.init.create(
                ctx, db_cluster_snapshot_identifier=value, db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.snapshot.init.create db_cluster_snapshot_identifier=value, db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="create_db_cluster_snapshot",
        op_kwargs={
            "DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier,
            "DBClusterIdentifier": db_cluster_identifier,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_cluster_snapshot_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a DB cluster snapshot. If the snapshot is being copied, the copy operation is terminated.  The DB cluster snapshot must be in the available state to be deleted.

    Args:
        db_cluster_snapshot_identifier(str): The identifier of the DB cluster snapshot to delete. Constraints: Must be the name of an existing DB cluster snapshot in the available state.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.snapshot.init.delete(
                ctx, db_cluster_snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.snapshot.init.delete db_cluster_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="delete_db_cluster_snapshot",
        op_kwargs={"DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier},
    )


async def describe_all(
    hub,
    ctx,
    db_cluster_identifier: str = None,
    db_cluster_snapshot_identifier: str = None,
    snapshot_type: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    include_shared: bool = None,
    include_public: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about DB cluster snapshots. This API action supports pagination.

    Args:
        db_cluster_identifier(str, optional): The ID of the DB cluster to retrieve the list of DB cluster snapshots for. This parameter can't be used in conjunction with the DBClusterSnapshotIdentifier parameter. This parameter is not case-sensitive. Constraints:   If supplied, must match the identifier of an existing DBCluster.  . Defaults to None.
        db_cluster_snapshot_identifier(str, optional): A specific DB cluster snapshot identifier to describe. This parameter can't be used in conjunction with the DBClusterIdentifier parameter. This value is stored as a lowercase string. Constraints:   If supplied, must match the identifier of an existing DBClusterSnapshot.   If this identifier is for an automated snapshot, the SnapshotType parameter must also be specified.  . Defaults to None.
        snapshot_type(str, optional): The type of DB cluster snapshots to be returned. You can specify one of the following values:    automated - Return all DB cluster snapshots that have been automatically taken by Amazon Neptune for my Amazon account.    manual - Return all DB cluster snapshots that have been taken by my AWS account.    shared - Return all manual DB cluster snapshots that have been shared to my Amazon account.    public - Return all DB cluster snapshots that have been marked as public.   If you don't specify a SnapshotType value, then both automated and manual DB cluster snapshots are returned. You can include shared DB cluster snapshots with these results by setting the IncludeShared parameter to true. You can include public DB cluster snapshots with these results by setting the IncludePublic parameter to true. The IncludeShared and IncludePublic parameters don't apply for SnapshotType values of manual or automated. The IncludePublic parameter doesn't apply when SnapshotType is set to shared. The IncludeShared parameter doesn't apply when SnapshotType is set to public. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeDBClusterSnapshots request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        include_shared(bool, optional): True to include shared manual DB cluster snapshots from other Amazon accounts that this AWS account has been given permission to copy or restore, and otherwise false. The default is false. You can give an Amazon account permission to restore a manual DB cluster snapshot from another Amazon account by the ModifyDBClusterSnapshotAttribute API action. Defaults to None.
        include_public(bool, optional): True to include manual DB cluster snapshots that are public and can be copied or restored by any Amazon account, and otherwise false. The default is false. The default is false. You can share a manual DB cluster snapshot as public by using the ModifyDBClusterSnapshotAttribute API action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.snapshot.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.snapshot.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_db_cluster_snapshots",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier,
            "SnapshotType": snapshot_type,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "IncludeShared": include_shared,
            "IncludePublic": include_public,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def register(hub, ctx, organization_id: str, entity_id: str, email: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers an existing and disabled user, group, or resource for Amazon WorkMail use by associating a mailbox and calendaring capabilities. It performs no change if the user, group, or resource is enabled and fails if the user, group, or resource is deleted. This operation results in the accumulation of costs. For more information, see Pricing. The equivalent console functionality for this operation is Enable.  Users can either be created by calling the CreateUser API operation or they can be synchronized from your directory. For more information, see DeregisterFromWorkMail.

    Args:
        organization_id(str): The identifier for the organization under which the user, group, or resource exists.
        entity_id(str): The identifier for the user, group, or resource to be updated.
        email(str): The email for the user, group, or resource to be updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.to_work_mail.register(
                ctx, organization_id=value, entity_id=value, email=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.to_work_mail.register organization_id=value, entity_id=value, email=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="register_to_work_mail",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "Email": email,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, replication_task_assessment_run_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a single premigration assessment run. This operation prevents any individual assessments from running if they haven't started running. It also attempts to cancel any individual assessments that are currently running.

    Args:
        replication_task_assessment_run_arn(str): Amazon Resource Name (ARN) of the premigration assessment run to be canceled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.assessment.run.cancel(
                ctx, replication_task_assessment_run_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.assessment.run.cancel replication_task_assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="cancel_replication_task_assessment_run",
        op_kwargs={
            "ReplicationTaskAssessmentRunArn": replication_task_assessment_run_arn
        },
    )


async def delete(hub, ctx, replication_task_assessment_run_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the record of a single premigration assessment run. This operation removes all metadata that DMS maintains about this assessment run. However, the operation leaves untouched all information about this assessment run that is stored in your Amazon S3 bucket.

    Args:
        replication_task_assessment_run_arn(str): Amazon Resource Name (ARN) of the premigration assessment run to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.assessment.run.delete(
                ctx, replication_task_assessment_run_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.assessment.run.delete replication_task_assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="delete_replication_task_assessment_run",
        op_kwargs={
            "ReplicationTaskAssessmentRunArn": replication_task_assessment_run_arn
        },
    )


async def describe_all(
    hub, ctx, filters: List = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a paginated list of premigration assessment runs based on filter settings. These filter settings can specify a combination of premigration assessment runs, migration tasks, replication instances, and assessment run status values.  This operation doesn't return information about individual assessments. For this information, see the DescribeReplicationTaskIndividualAssessments operation.

    Args:
        filters(List, optional): Filters applied to the premigration assessment runs described in the form of key-value pairs. Valid filter names: replication-task-assessment-run-arn, replication-task-arn, replication-instance-arn, status . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.assessment.run.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.assessment.run.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_replication_task_assessment_runs",
        op_kwargs={"Filters": filters, "MaxRecords": max_records, "Marker": marker},
    )


async def start(
    hub,
    ctx,
    replication_task_arn: str,
    service_access_role_arn: str,
    result_location_bucket: str,
    assessment_run_name: str,
    result_location_folder: str = None,
    result_encryption_mode: str = None,
    result_kms_key_arn: str = None,
    include_only: List = None,
    exclude: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a new premigration assessment run for one or more individual assessments of a migration task. The assessments that you can specify depend on the source and target database engine and the migration type defined for the given task. To run this operation, your migration task must already be created. After you run this operation, you can review the status of each individual assessment. You can also run the migration task manually after the assessment run and its individual assessments complete.

    Args:
        replication_task_arn(str): Amazon Resource Name (ARN) of the migration task associated with the premigration assessment run that you want to start.
        service_access_role_arn(str): ARN of the service role needed to start the assessment run. The role must allow the iam:PassRole action.
        result_location_bucket(str): Amazon S3 bucket where you want DMS to store the results of this assessment run.
        result_location_folder(str, optional): Folder within an Amazon S3 bucket where you want DMS to store the results of this assessment run. Defaults to None.
        result_encryption_mode(str, optional): Encryption mode that you can specify to encrypt the results of this assessment run. If you don't specify this request parameter, DMS stores the assessment run results without encryption. You can specify one of the options following:    "SSE_S3" – The server-side encryption provided as a default by Amazon S3.    "SSE_KMS" – Key Management Service (KMS) encryption. This encryption can use either a custom KMS encryption key that you specify or the default KMS encryption key that DMS provides.  . Defaults to None.
        result_kms_key_arn(str, optional): ARN of a custom KMS encryption key that you specify when you set ResultEncryptionMode to "SSE_KMS". Defaults to None.
        assessment_run_name(str): Unique name to identify the assessment run.
        include_only(List, optional): Space-separated list of names for specific individual assessments that you want to include. These names come from the default list of individual assessments that DMS supports for the associated migration task. This task is specified by ReplicationTaskArn.  You can't set a value for IncludeOnly if you also set a value for Exclude in the API operation.  To identify the names of the default individual assessments that DMS supports for the associated migration task, run the DescribeApplicableIndividualAssessments operation using its own ReplicationTaskArn request parameter. . Defaults to None.
        exclude(List, optional): Space-separated list of names for specific individual assessments that you want to exclude. These names come from the default list of individual assessments that DMS supports for the associated migration task. This task is specified by ReplicationTaskArn.  You can't set a value for Exclude if you also set a value for IncludeOnly in the API operation. To identify the names of the default individual assessments that DMS supports for the associated migration task, run the DescribeApplicableIndividualAssessments operation using its own ReplicationTaskArn request parameter. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.assessment.run.start(
                ctx,
                replication_task_arn=value,
                service_access_role_arn=value,
                result_location_bucket=value,
                assessment_run_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.assessment.run.start replication_task_arn=value, service_access_role_arn=value, result_location_bucket=value, assessment_run_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="start_replication_task_assessment_run",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "ServiceAccessRoleArn": service_access_role_arn,
            "ResultLocationBucket": result_location_bucket,
            "ResultLocationFolder": result_location_folder,
            "ResultEncryptionMode": result_encryption_mode,
            "ResultKmsKeyArn": result_kms_key_arn,
            "AssessmentRunName": assessment_run_name,
            "IncludeOnly": include_only,
            "Exclude": exclude,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, instance_id: str, hours_of_operation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Describes the hours of operation.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        hours_of_operation_id(str): The identifier for the hours of operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.hour_of_operation.describe(
                ctx, instance_id=value, hours_of_operation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.hour_of_operation.describe instance_id=value, hours_of_operation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_hours_of_operation",
        op_kwargs={
            "InstanceId": instance_id,
            "HoursOfOperationId": hours_of_operation_id,
        },
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the hours of operation for the specified Amazon Connect instance. For more information about hours of operation, see Set the Hours of Operation for a Queue in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.hour_of_operation.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.hour_of_operation.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_hours_of_operations",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    repository_name: str,
    repository_description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new, empty repository.

    Args:
        repository_name(str): The name of the new repository to be created.  The repository name must be unique across the calling AWS account. Repository names are limited to 100 alphanumeric, dash, and underscore characters, and cannot include certain characters. For more information about the limits on repository names, see Limits in the AWS CodeCommit User Guide. The suffix .git is prohibited. .
        repository_description(str, optional): A comment or description about the new repository.  The description field for a repository accepts all HTML characters and all valid Unicode characters. Applications that do not HTML-encode the description and display it in a webpage can expose users to potentially malicious code. Make sure that you HTML-encode the description field in any application that uses this API to display the repository description on a webpage. . Defaults to None.
        tags(Dict, optional): One or more tag key-value pairs to use when tagging this repository. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.init.create(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.init.create repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_repository",
        op_kwargs={
            "repositoryName": repository_name,
            "repositoryDescription": repository_description,
            "tags": tags,
        },
    )


async def delete(hub, ctx, repository_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a repository. If a specified repository was already deleted, a null repository ID is returned.  Deleting a repository also deletes all associated objects and metadata. After a repository is deleted, all future push calls to the deleted repository fail.

    Args:
        repository_name(str): The name of the repository to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.init.delete(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.init.delete repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="delete_repository",
        op_kwargs={"repositoryName": repository_name},
    )


async def get(hub, ctx, repository_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a repository.  The description field for a repository accepts all HTML characters and all valid Unicode characters. Applications that do not HTML-encode the description and display it in a webpage can expose users to potentially malicious code. Make sure that you HTML-encode the description field in any application that uses this API to display the repository description on a webpage.

    Args:
        repository_name(str): The name of the repository to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.init.get(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.init.get repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_repository",
        op_kwargs={"repositoryName": repository_name},
    )


async def list_all(
    hub, ctx, next_token: str = None, sort_by: str = None, order: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more repositories.

    Args:
        next_token(str, optional): An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved. Defaults to None.
        sort_by(str, optional): The criteria used to sort the results of a list repositories operation. Defaults to None.
        order(str, optional): The order in which to sort the results of a list repositories operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="list_repositories",
        op_kwargs={"nextToken": next_token, "sortBy": sort_by, "order": order},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "for_provisioned_permission_set"


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    instance_arn: str,
    permission_set_arn: str,
    provisioning_status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the Amazon Web Services accounts where the specified permission set is provisioned.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the PermissionSet from which the associated Amazon Web Services accounts will be listed.
        provisioning_status(str, optional): The permission set provisioning status for an Amazon Web Services account. Defaults to None.
        max_results(int, optional): The maximum number of results to display for the PermissionSet. Defaults to None.
        next_token(str, optional): The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.account.for_provisioned_permission_set_.list(
                ctx, instance_arn=value, permission_set_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.account.for_provisioned_permission_set.list instance_arn=value, permission_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="list_accounts_for_provisioned_permission_set",
        op_kwargs={
            "InstanceArn": instance_arn,
            "PermissionSetArn": permission_set_arn,
            "ProvisioningStatus": provisioning_status,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, data_source_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Assigns the DELETED status to a DataSource, rendering it unusable. After using the DeleteDataSource operation, you can use the GetDataSource operation to verify that the status of the DataSource changed to DELETED.  Caution: The results of the DeleteDataSource operation are irreversible.

    Args:
        data_source_id(str): A user-supplied ID that uniquely identifies the DataSource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.data_source.init.delete(
                ctx, data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.data_source.init.delete data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="delete_data_source",
        op_kwargs={"DataSourceId": data_source_id},
    )


async def describe_all(
    hub,
    ctx,
    filter_variable: str = None,
    eq: str = None,
    gt: str = None,
    lt: str = None,
    ge: str = None,
    le: str = None,
    ne: str = None,
    prefix: str = None,
    sort_order: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DataSource that match the search criteria in the request.

    Args:
        filter_variable(str, optional): Use one of the following variables to filter a list of DataSource:    CreatedAt - Sets the search criteria to DataSource creation dates.    Status - Sets the search criteria to DataSource statuses.    Name - Sets the search criteria to the contents of DataSource Name.    DataUri - Sets the search criteria to the URI of data files used to create the DataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory.    IAMUser - Sets the search criteria to the user account that invoked the DataSource creation.  . Defaults to None.
        eq(str, optional): The equal to operator. The DataSource results will have FilterVariable values that exactly match the value specified with EQ. Defaults to None.
        gt(str, optional): The greater than operator. The DataSource results will have FilterVariable values that are greater than the value specified with GT. Defaults to None.
        lt(str, optional): The less than operator. The DataSource results will have FilterVariable values that are less than the value specified with LT. Defaults to None.
        ge(str, optional): The greater than or equal to operator. The DataSource results will have FilterVariable values that are greater than or equal to the value specified with GE. . Defaults to None.
        le(str, optional): The less than or equal to operator. The DataSource results will have FilterVariable values that are less than or equal to the value specified with LE. Defaults to None.
        ne(str, optional): The not equal to operator. The DataSource results will have FilterVariable values not equal to the value specified with NE. Defaults to None.
        prefix(str, optional): A string that is found at the beginning of a variable, such as Name or Id. For example, a DataSource could have the Name 2014-09-09-HolidayGiftMailer. To search for this DataSource, select Name for the FilterVariable and any of the following strings for the Prefix:    2014-09   2014-09-09   2014-09-09-Holiday  . Defaults to None.
        sort_order(str, optional): A two-value parameter that determines the sequence of the resulting list of DataSource.    asc - Arranges the list in ascending order (A-Z, 0-9).    dsc - Arranges the list in descending order (Z-A, 9-0).   Results are sorted by FilterVariable. Defaults to None.
        next_token(str, optional): The ID of the page in the paginated results. Defaults to None.
        limit(int, optional):  The maximum number of DataSource to include in the result. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.data_source.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.data_source.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="describe_data_sources",
        op_kwargs={
            "FilterVariable": filter_variable,
            "EQ": eq,
            "GT": gt,
            "LT": lt,
            "GE": ge,
            "LE": le,
            "NE": ne,
            "Prefix": prefix,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def get(hub, ctx, data_source_id: str, verbose: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource.  GetDataSource provides results in normal or verbose format. The verbose format adds the schema description and the list of files pointed to by the DataSource to the normal format.

    Args:
        data_source_id(str): The ID assigned to the DataSource at creation.
        verbose(bool, optional): Specifies whether the GetDataSource operation should return DataSourceSchema. If true, DataSourceSchema is returned. If false, DataSourceSchema is not returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.data_source.init.get(ctx, data_source_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.data_source.init.get data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="get_data_source",
        op_kwargs={"DataSourceId": data_source_id, "Verbose": verbose},
    )


async def update(hub, ctx, data_source_id: str, data_source_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the DataSourceName of a DataSource. You can use the GetDataSource operation to view the contents of the updated data element.

    Args:
        data_source_id(str): The ID assigned to the DataSource during creation.
        data_source_name(str): A new user-supplied name or description of the DataSource that will replace the current description. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.data_source.init.update(
                ctx, data_source_id=value, data_source_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.data_source.init.update data_source_id=value, data_source_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="update_data_source",
        op_kwargs={"DataSourceId": data_source_id, "DataSourceName": data_source_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    action_name: str,
    source: Dict,
    action_type: str,
    description: str = None,
    status: str = None,
    properties: Dict = None,
    metadata_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an action. An action is a lineage tracking entity that represents an action or activity. For example, a model deployment or an HPO job. Generally, an action involves at least one input or output artifact. For more information, see Amazon SageMaker ML Lineage Tracking.   CreateAction can only be invoked from within an SageMaker managed environment. This includes SageMaker training jobs, processing jobs, transform jobs, and SageMaker notebooks. A call to CreateAction from outside one of these environments results in an error.

    Args:
        action_name(str): The name of the action. Must be unique to your account in an Amazon Web Services Region.
        source(Dict): The source type, ID, and URI.
        action_type(str): The action type.
        description(str, optional): The description of the action. Defaults to None.
        status(str, optional): The status of the action. Defaults to None.
        properties(Dict, optional): A list of properties to add to the action. Defaults to None.
        metadata_properties(Dict, optional): Metadata properties of the tracking entity, trial, or trial component. Defaults to None.
        tags(List, optional): A list of tags to apply to the action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.action.create(
                ctx, action_name=value, source=value, action_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.action.create action_name=value, source=value, action_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_action",
        op_kwargs={
            "ActionName": action_name,
            "Source": source,
            "ActionType": action_type,
            "Description": description,
            "Status": status,
            "Properties": properties,
            "MetadataProperties": metadata_properties,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, action_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an action.

    Args:
        action_name(str): The name of the action to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.action.delete(ctx, action_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.action.delete action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_action",
        op_kwargs={"ActionName": action_name},
    )


async def describe(hub, ctx, action_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an action.

    Args:
        action_name(str): The name of the action to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.action.describe(ctx, action_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.action.describe action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_action",
        op_kwargs={"ActionName": action_name},
    )


async def list_all(
    hub,
    ctx,
    source_uri: str = None,
    action_type: str = None,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the actions in your account and their properties.

    Args:
        source_uri(str, optional): A filter that returns only actions with the specified source URI. Defaults to None.
        action_type(str, optional): A filter that returns only actions of the specified type. Defaults to None.
        created_after(str, optional): A filter that returns only actions created on or after the specified time. Defaults to None.
        created_before(str, optional): A filter that returns only actions created on or before the specified time. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order. The default value is Descending. Defaults to None.
        next_token(str, optional): If the previous call to ListActions didn't return the full set of actions, the call returns a token for getting the next set of actions. Defaults to None.
        max_results(int, optional): The maximum number of actions to return in the response. The default value is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.action.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.action.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_actions",
        op_kwargs={
            "SourceUri": source_uri,
            "ActionType": action_type,
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    action_name: str,
    description: str = None,
    status: str = None,
    properties: Dict = None,
    properties_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an action.

    Args:
        action_name(str): The name of the action to update.
        description(str, optional): The new description for the action. Defaults to None.
        status(str, optional): The new status for the action. Defaults to None.
        properties(Dict, optional): The new list of properties. Overwrites the current property list. Defaults to None.
        properties_to_remove(List, optional): A list of properties to remove. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.action.update(ctx, action_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.action.update action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_action",
        op_kwargs={
            "ActionName": action_name,
            "Description": description,
            "Status": status,
            "Properties": properties,
            "PropertiesToRemove": properties_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of tags that are associated with a resource group, specified by an ARN.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:GetTags

    Args:
        arn(str): The ARN of the resource group whose tags you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.tags.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.tags.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="get_tags",
        op_kwargs={"Arn": arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    input_name: str,
    input_definition: Dict,
    input_description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an input.

    Args:
        input_name(str): The name you want to give to the input.
        input_description(str, optional): A brief description of the input. Defaults to None.
        input_definition(Dict): The definition of the input.
        tags(List, optional): Metadata that can be used to manage the input. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.input_.init.create(
                ctx, input_name=value, input_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.input_.init.create input_name=value, input_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="create_input",
        op_kwargs={
            "inputName": input_name,
            "inputDescription": input_description,
            "inputDefinition": input_definition,
            "tags": tags,
        },
    )


async def delete(hub, ctx, input_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an input.

    Args:
        input_name(str): The name of the input to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.input_.init.delete(ctx, input_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.input_.init.delete input_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="delete_input",
        op_kwargs={"inputName": input_name},
    )


async def describe(hub, ctx, input_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an input.

    Args:
        input_name(str): The name of the input.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.input_.init.describe(ctx, input_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.input_.init.describe input_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="describe_input",
        op_kwargs={"inputName": input_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the inputs you have created.

    Args:
        next_token(str, optional): The token that you can use to return the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.input_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.input_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="list_inputs",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub, ctx, input_name: str, input_definition: Dict, input_description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an input.

    Args:
        input_name(str): The name of the input you want to update.
        input_description(str, optional): A brief description of the input. Defaults to None.
        input_definition(Dict): The definition of the input.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.input_.init.update(
                ctx, input_name=value, input_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.input_.init.update input_name=value, input_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="update_input",
        op_kwargs={
            "inputName": input_name,
            "inputDescription": input_description,
            "inputDefinition": input_definition,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dry_run: bool = None,
    acceptance_required: bool = None,
    private_dns_name: str = None,
    network_load_balancer_arns: List = None,
    gateway_load_balancer_arns: List = None,
    client_token: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a VPC endpoint service configuration to which service consumers (AWS accounts, IAM users, and IAM roles) can connect. To create an endpoint service configuration, you must first create one of the following for your service:   A Network Load Balancer. Service consumers connect to your service using an interface endpoint.   A Gateway Load Balancer. Service consumers connect to your service using a Gateway Load Balancer endpoint.   For more information, see VPC Endpoint Services in the Amazon Virtual Private Cloud User Guide.  If you set the private DNS name, you must prove that you own the private DNS domain name. For more information, see VPC Endpoint Service Private DNS Name Verification in the Amazon Virtual Private Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        acceptance_required(bool, optional): Indicates whether requests from service consumers to create an endpoint to your service must be accepted. To accept a request, use AcceptVpcEndpointConnections. Defaults to None.
        private_dns_name(str, optional): (Interface endpoint configuration) The private DNS name to assign to the VPC endpoint service. Defaults to None.
        network_load_balancer_arns(List, optional): The Amazon Resource Names (ARNs) of one or more Network Load Balancers for your service. Defaults to None.
        gateway_load_balancer_arns(List, optional): The Amazon Resource Names (ARNs) of one or more Gateway Load Balancers. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        tag_specifications(List, optional): The tags to associate with the service. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.configuration.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.configuration.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpc_endpoint_service_configuration",
        op_kwargs={
            "DryRun": dry_run,
            "AcceptanceRequired": acceptance_required,
            "PrivateDnsName": private_dns_name,
            "NetworkLoadBalancerArns": network_load_balancer_arns,
            "GatewayLoadBalancerArns": gateway_load_balancer_arns,
            "ClientToken": client_token,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete_multiple(hub, ctx, service_ids: List, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more VPC endpoint service configurations in your account. Before you delete the endpoint service configuration, you must reject any Available or PendingAcceptance interface endpoint connections that are attached to the service.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_ids(List): The IDs of one or more services.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.configuration.delete_multiple(
                ctx, service_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.configuration.delete_multiple service_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpc_endpoint_service_configurations",
        op_kwargs={"DryRun": dry_run, "ServiceIds": service_ids},
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    service_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the VPC endpoint service configurations in your account (your services).

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_ids(List, optional): The IDs of one or more services. Defaults to None.
        filters(List, optional): One or more filters.    service-name - The name of the service.    service-id - The ID of the service.    service-state - The state of the service (Pending | Available | Deleting | Deleted | Failed).     tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_endpoint_service_configurations",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceIds": service_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    service_id: str,
    dry_run: bool = None,
    private_dns_name: str = None,
    remove_private_dns_name: bool = None,
    acceptance_required: bool = None,
    add_network_load_balancer_arns: List = None,
    remove_network_load_balancer_arns: List = None,
    add_gateway_load_balancer_arns: List = None,
    remove_gateway_load_balancer_arns: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the attributes of your VPC endpoint service configuration. You can change the Network Load Balancers or Gateway Load Balancers for your service, and you can specify whether acceptance is required for requests to connect to your endpoint service through an interface VPC endpoint. If you set or modify the private DNS name, you must prove that you own the private DNS domain name. For more information, see VPC Endpoint Service Private DNS Name Verification in the Amazon Virtual Private Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str): The ID of the service.
        private_dns_name(str, optional): (Interface endpoint configuration) The private DNS name to assign to the endpoint service. Defaults to None.
        remove_private_dns_name(bool, optional): (Interface endpoint configuration) Removes the private DNS name of the endpoint service. Defaults to None.
        acceptance_required(bool, optional): Indicates whether requests to create an endpoint to your service must be accepted. Defaults to None.
        add_network_load_balancer_arns(List, optional): The Amazon Resource Names (ARNs) of Network Load Balancers to add to your service configuration. Defaults to None.
        remove_network_load_balancer_arns(List, optional): The Amazon Resource Names (ARNs) of Network Load Balancers to remove from your service configuration. Defaults to None.
        add_gateway_load_balancer_arns(List, optional): The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your service configuration. Defaults to None.
        remove_gateway_load_balancer_arns(List, optional): The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from your service configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.configuration.modify(
                ctx, service_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.configuration.modify service_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpc_endpoint_service_configuration",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceId": service_id,
            "PrivateDnsName": private_dns_name,
            "RemovePrivateDnsName": remove_private_dns_name,
            "AcceptanceRequired": acceptance_required,
            "AddNetworkLoadBalancerArns": add_network_load_balancer_arns,
            "RemoveNetworkLoadBalancerArns": remove_network_load_balancer_arns,
            "AddGatewayLoadBalancerArns": add_gateway_load_balancer_arns,
            "RemoveGatewayLoadBalancerArns": remove_gateway_load_balancer_arns,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    display_name: str = None,
    encryption_key: str = None,
    pipeline_provisioning: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a service template. The administrator creates a service template to define standardized infrastructure and an optional CICD service pipeline. Developers, in turn, select the service template from AWS Proton. If the selected service template includes a service pipeline definition, they provide a link to their source code repository. AWS Proton then deploys and manages the infrastructure defined by the selected service template. For more information, see Service Templates in the AWS Proton Administrator Guide.

    Args:
        description(str, optional): A description of the service template. Defaults to None.
        display_name(str, optional): The name of the service template as displayed in the developer interface. Defaults to None.
        encryption_key(str, optional): A customer provided encryption key that's used to encrypt data. Defaults to None.
        name(str): The name of the service template.
        pipeline_provisioning(str, optional): AWS Proton includes a service pipeline for your service by default. When included, this parameter indicates that an AWS Proton service pipeline won't be included for your service. Once specified, this parameter can't be changed. For more information, see Service template bundles in the AWS Proton Administrator Guide. Defaults to None.
        tags(List, optional): Create tags for your service template. For more information, see AWS Proton resources and tagging in the AWS Proton Administrator Guide or AWS Proton User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="create_service_template",
        op_kwargs={
            "description": description,
            "displayName": display_name,
            "encryptionKey": encryption_key,
            "name": name,
            "pipelineProvisioning": pipeline_provisioning,
            "tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    If no other major or minor versions of the service template exist, delete the service template.

    Args:
        name(str): The name of the service template to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="delete_service_template",
        op_kwargs={"name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Get detail data for a service template.

    Args:
        name(str): The name of the service template that you want to get detail data for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="get_service_template",
        op_kwargs={"name": name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List service templates with detail data.

    Args:
        max_results(int, optional): The maximum number of service templates to list. Defaults to None.
        next_token(str, optional): A token to indicate the location of the next service template in the array of service templates, after the list of service templates previously requested. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="list_service_templates",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub, ctx, name: str, description: str = None, display_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update a service template.

    Args:
        description(str, optional): A description of the service template update. Defaults to None.
        display_name(str, optional): The name of the service template to update as displayed in the developer interface. Defaults to None.
        name(str): The name of the service template to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_service_template",
        op_kwargs={
            "description": description,
            "displayName": display_name,
            "name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, web_acl_arn: str, resource_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of the Amazon Resource Names (ARNs) for the regional resources that are associated with the specified web ACL. If you want the list of Amazon CloudFront resources, use the CloudFront call ListDistributionsByWebACLId.

    Args:
        web_acl_arn(str): The Amazon Resource Name (ARN) of the web ACL.
        resource_type(str, optional): Used for web ACLs that are scoped for regional applications. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.resource.for_web_acl.list(ctx, web_acl_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.resource.for_web_acl.list web_acl_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_resources_for_web_acl",
        op_kwargs={"WebACLArn": web_acl_arn, "ResourceType": resource_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def request(
    hub, ctx, info_type: str, environment_id: str = None, environment_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Initiates a request to compile the specified type of information of the deployed environment.  Setting the InfoType to tail compiles the last lines from the application server log files of every Amazon EC2 instance in your environment.   Setting the InfoType to bundle compresses the application server log files for every Amazon EC2 instance into a .zip file. Legacy and .NET containers do not support bundle logs.   Use RetrieveEnvironmentInfo to obtain the set of logs.  Related Topics    RetrieveEnvironmentInfo

    Args:
        environment_id(str, optional): The ID of the environment of the requested data. If no such environment is found, RequestEnvironmentInfo returns an InvalidParameterValue error.  Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment of the requested data. If no such environment is found, RequestEnvironmentInfo returns an InvalidParameterValue error.  Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        info_type(str): The type of information to request.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.info.request(ctx, info_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.info.request info_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="request_environment_info",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
            "InfoType": info_type,
        },
    )


async def retrieve(
    hub, ctx, info_type: str, environment_id: str = None, environment_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the compiled information from a RequestEnvironmentInfo request. Related Topics    RequestEnvironmentInfo

    Args:
        environment_id(str, optional): The ID of the data's environment. If no such environment is found, returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. Defaults to None.
        environment_name(str, optional): The name of the data's environment.  If no such environment is found, returns an InvalidParameterValue error.   Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        info_type(str): The type of information to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.info.retrieve(ctx, info_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.info.retrieve info_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="retrieve_environment_info",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
            "InfoType": info_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags_to_add: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds tags to a resource. A tag is a label you can assign to an Amazon Web Services resource. In Glue, you can tag only certain resources. For information about what resources you can tag, see Amazon Web Services Tags in Glue.

    Args:
        resource_arn(str): The ARN of the Glue resource to which to add the tags. For more information about Glue resource ARNs, see the Glue ARN string pattern.
        tags_to_add(Dict): Tags to add to this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.resource.init.tag(
                ctx, resource_arn=value, tags_to_add=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.resource.init.tag resource_arn=value, tags_to_add=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagsToAdd": tags_to_add},
    )


async def untag(hub, ctx, resource_arn: str, tags_to_remove: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource from which to remove the tags.
        tags_to_remove(List): Tags to remove from this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.resource.init.untag(
                ctx, resource_arn=value, tags_to_remove=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.resource.init.untag resource_arn=value, tags_to_remove=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagsToRemove": tags_to_remove},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    policy: str = None,
    description: str = None,
    key_usage: str = None,
    customer_master_key_spec: str = None,
    origin: str = None,
    custom_key_store_id: str = None,
    bypass_policy_lockout_safety_check: bool = None,
    tags: List = None,
    multi_region: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a unique customer managed customer master key (CMK) in your AWS account and Region. You can use the CreateKey operation to create symmetric or asymmetric CMKs.    Symmetric CMKs contain a 256-bit symmetric key that never leaves AWS KMS unencrypted. To use the CMK, you must call AWS KMS. You can use a symmetric CMK to encrypt and decrypt small amounts of data, but they are typically used to generate data keys and data keys pairs. For details, see GenerateDataKey and GenerateDataKeyPair.    Asymmetric CMKs can contain an RSA key pair or an Elliptic Curve (ECC) key pair. The private key in an asymmetric CMK never leaves AWS KMS unencrypted. However, you can use the GetPublicKey operation to download the public key so it can be used outside of AWS KMS. CMKs with RSA key pairs can be used to encrypt or decrypt data or sign and verify messages (but not both). CMKs with ECC key pairs can be used only to sign and verify messages.   For information about symmetric and asymmetric CMKs, see Using Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide. To create different types of CMKs, use the following guidance:  Asymmetric CMKs  To create an asymmetric CMK, use the CustomerMasterKeySpec parameter to specify the type of key material in the CMK. Then, use the KeyUsage parameter to determine whether the CMK will be used to encrypt and decrypt or sign and verify. You can't change these properties after the CMK is created.    Symmetric CMKs  When creating a symmetric CMK, you don't need to specify the CustomerMasterKeySpec or KeyUsage parameters. The default value for CustomerMasterKeySpec, SYMMETRIC_DEFAULT, and the default value for KeyUsage, ENCRYPT_DECRYPT, are the only valid values for symmetric CMKs.     Multi-Region primary keys Imported key material  To create a multi-Region primary key in the local AWS Region, use the MultiRegion parameter with a value of True. To create a multi-Region replica key, that is, a CMK with the same key ID and key material as a primary key, but in a different AWS Region, use the ReplicateKey operation. To change a replica key to a primary key, and its primary key to a replica key, use the UpdatePrimaryRegion operation. This operation supports multi-Region keys, an AWS KMS feature that lets you create multiple interoperable CMKs in different AWS Regions. Because these CMKs have the same key ID, key material, and other metadata, you can use them to encrypt data in one AWS Region and decrypt it in a different AWS Region without making a cross-Region call or exposing the plaintext data. For more information about multi-Region keys, see Using multi-Region keys in the AWS Key Management Service Developer Guide. You can create symmetric and asymmetric multi-Region keys and multi-Region keys with imported key material. You cannot create multi-Region keys in a custom key store.     To import your own key material, begin by creating a symmetric CMK with no key material. To do this, use the Origin parameter of CreateKey with a value of EXTERNAL. Next, use GetParametersForImport operation to get a public key and import token, and use the public key to encrypt your key material. Then, use ImportKeyMaterial with your import token to import the key material. For step-by-step instructions, see Importing Key Material in the  AWS Key Management Service Developer Guide . You cannot import the key material into an asymmetric CMK. To create a multi-Region primary key with imported key material, use the Origin parameter of CreateKey with a value of EXTERNAL and the MultiRegion parameter with a value of True. To create replicas of the multi-Region primary key, use the ReplicateKey operation. For more information about multi-Region keys, see Using multi-Region keys in the AWS Key Management Service Developer Guide.    Custom key store  To create a symmetric CMK in a custom key store, use the CustomKeyStoreId parameter to specify the custom key store. You must also use the Origin parameter with a value of AWS_CLOUDHSM. The AWS CloudHSM cluster that is associated with the custom key store must have at least two active HSMs in different Availability Zones in the AWS Region.  You cannot create an asymmetric CMK or a multi-Region CMK in a custom key store. For information about custom key stores in AWS KMS see Using Custom Key Stores in the  AWS Key Management Service Developer Guide .    Cross-account use: No. You cannot use this operation to create a CMK in a different AWS account.  Required permissions: kms:CreateKey (IAM policy). To use the Tags parameter, kms:TagResource (IAM policy). For examples and information about related permissions, see Allow a user to create CMKs in the AWS Key Management Service Developer Guide.  Related operations:     DescribeKey     ListKeys     ScheduleKeyDeletion

    Args:
        policy(str, optional): The key policy to attach to the CMK. If you provide a key policy, it must meet the following criteria:   If you don't set BypassPolicyLockoutSafetyCheck to true, the key policy must allow the principal that is making the CreateKey request to make a subsequent PutKeyPolicy request on the CMK. This reduces the risk that the CMK becomes unmanageable. For more information, refer to the scenario in the Default Key Policy section of the  AWS Key Management Service Developer Guide .   Each statement in the key policy must contain one or more principals. The principals in the key policy must exist and be visible to AWS KMS. When you create a new AWS principal (for example, an IAM user or role), you might need to enforce a delay before including the new principal in a key policy because the new principal might not be immediately visible to AWS KMS. For more information, see Changes that I make are not always immediately visible in the AWS Identity and Access Management User Guide.   If you do not provide a key policy, AWS KMS attaches a default key policy to the CMK. For more information, see Default Key Policy in the AWS Key Management Service Developer Guide.  The key policy size quota is 32 kilobytes (32768 bytes). For help writing and formatting a JSON policy document, see the IAM JSON Policy Reference in the  IAM User Guide . Defaults to None.
        description(str, optional): A description of the CMK. Use a description that helps you decide whether the CMK is appropriate for a task. The default value is an empty string (no description). Defaults to None.
        key_usage(str, optional): Determines the cryptographic operations for which you can use the CMK. The default value is ENCRYPT_DECRYPT. This parameter is required only for asymmetric CMKs. You can't change the KeyUsage value after the CMK is created. Select only one valid value.   For symmetric CMKs, omit the parameter or specify ENCRYPT_DECRYPT.   For asymmetric CMKs with RSA key material, specify ENCRYPT_DECRYPT or SIGN_VERIFY.   For asymmetric CMKs with ECC key material, specify SIGN_VERIFY.  . Defaults to None.
        customer_master_key_spec(str, optional): Specifies the type of CMK to create. The default value, SYMMETRIC_DEFAULT, creates a CMK with a 256-bit symmetric key for encryption and decryption. For help choosing a key spec for your CMK, see How to Choose Your CMK Configuration in the AWS Key Management Service Developer Guide. The CustomerMasterKeySpec determines whether the CMK contains a symmetric key or an asymmetric key pair. It also determines the encryption algorithms or signing algorithms that the CMK supports. You can't change the CustomerMasterKeySpec after the CMK is created. To further restrict the algorithms that can be used with the CMK, use a condition key in its key policy or IAM policy. For more information, see kms:EncryptionAlgorithm or kms:Signing Algorithm in the AWS Key Management Service Developer Guide.   AWS services that are integrated with AWS KMS use symmetric CMKs to protect your data. These services do not support asymmetric CMKs. For help determining whether a CMK is symmetric or asymmetric, see Identifying Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide.  AWS KMS supports the following key specs for CMKs:   Symmetric key (default)    SYMMETRIC_DEFAULT (AES-256-GCM)     Asymmetric RSA key pairs    RSA_2048     RSA_3072     RSA_4096      Asymmetric NIST-recommended elliptic curve key pairs    ECC_NIST_P256 (secp256r1)    ECC_NIST_P384 (secp384r1)    ECC_NIST_P521 (secp521r1)     Other asymmetric elliptic curve key pairs    ECC_SECG_P256K1 (secp256k1), commonly used for cryptocurrencies.    . Defaults to None.
        origin(str, optional): The source of the key material for the CMK. You cannot change the origin after you create the CMK. The default is AWS_KMS, which means that AWS KMS creates the key material. To create a CMK with no key material (for imported key material), set the value to EXTERNAL. For more information about importing key material into AWS KMS, see Importing Key Material in the AWS Key Management Service Developer Guide. This value is valid only for symmetric CMKs. To create a CMK in an AWS KMS custom key store and create its key material in the associated AWS CloudHSM cluster, set this value to AWS_CLOUDHSM. You must also use the CustomKeyStoreId parameter to identify the custom key store. This value is valid only for symmetric CMKs. Defaults to None.
        custom_key_store_id(str, optional): Creates the CMK in the specified custom key store and the key material in its associated AWS CloudHSM cluster. To create a CMK in a custom key store, you must also specify the Origin parameter with a value of AWS_CLOUDHSM. The AWS CloudHSM cluster that is associated with the custom key store must have at least two active HSMs, each in a different Availability Zone in the Region. This parameter is valid only for symmetric CMKs and regional CMKs. You cannot create an asymmetric CMK or a multi-Region CMK in a custom key store. To find the ID of a custom key store, use the DescribeCustomKeyStores operation. The response includes the custom key store ID and the ID of the AWS CloudHSM cluster. This operation is part of the Custom Key Store feature feature in AWS KMS, which combines the convenience and extensive integration of AWS KMS with the isolation and control of a single-tenant key store. Defaults to None.
        bypass_policy_lockout_safety_check(bool, optional): A flag to indicate whether to bypass the key policy lockout safety check.  Setting this value to true increases the risk that the CMK becomes unmanageable. Do not set this value to true indiscriminately. For more information, refer to the scenario in the Default Key Policy section in the  AWS Key Management Service Developer Guide .  Use this parameter only when you include a policy in the request and you intend to prevent the principal that is making the request from making a subsequent PutKeyPolicy request on the CMK. The default value is false. Defaults to None.
        tags(List, optional): Assigns one or more tags to the CMK. Use this parameter to tag the CMK when it is created. To tag an existing CMK, use the TagResource operation.  Tagging or untagging a CMK can allow or deny permission to the CMK. For details, see Using ABAC in AWS KMS in the AWS Key Management Service Developer Guide.  To use this parameter, you must have kms:TagResource permission in an IAM policy. Each tag consists of a tag key and a tag value. Both the tag key and the tag value are required, but the tag value can be an empty (null) string. You cannot have more than one tag on a CMK with the same tag key. If you specify an existing tag key with a different tag value, AWS KMS replaces the current tag value with the specified one. When you assign tags to an AWS resource, AWS generates a cost allocation report with usage and costs aggregated by tags. Tags can also be used to control access to a CMK. For details, see Tagging Keys. Defaults to None.
        multi_region(bool, optional): Creates a multi-Region primary key that you can replicate into other AWS Regions. You cannot change this value after you create the CMK.  For a multi-Region key, set this parameter to True. For a single-Region CMK, omit this parameter or set it to False. The default value is False. This operation supports multi-Region keys, an AWS KMS feature that lets you create multiple interoperable CMKs in different AWS Regions. Because these CMKs have the same key ID, key material, and other metadata, you can use them to encrypt data in one AWS Region and decrypt it in a different AWS Region without making a cross-Region call or exposing the plaintext data. For more information about multi-Region keys, see Using multi-Region keys in the AWS Key Management Service Developer Guide. This value creates a primary key, not a replica. To create a replica key, use the ReplicateKey operation.  You can create a symmetric or asymmetric multi-Region CMK, and you can create a multi-Region CMK with imported key material. However, you cannot create a multi-Region CMK in a custom key store. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="create_key",
        op_kwargs={
            "Policy": policy,
            "Description": description,
            "KeyUsage": key_usage,
            "CustomerMasterKeySpec": customer_master_key_spec,
            "Origin": origin,
            "CustomKeyStoreId": custom_key_store_id,
            "BypassPolicyLockoutSafetyCheck": bypass_policy_lockout_safety_check,
            "Tags": tags,
            "MultiRegion": multi_region,
        },
    )


async def describe(hub, ctx, key_id: str, grant_tokens: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides detailed information about a customer master key (CMK). You can run DescribeKey on a customer managed CMK or an AWS managed CMK. This detailed information includes the key ARN, creation date (and deletion date, if applicable), the key state, and the origin and expiration date (if any) of the key material. For CMKs in custom key stores, it includes information about the custom key store, such as the key store ID and the AWS CloudHSM cluster ID. It includes fields, like KeySpec, that help you distinguish symmetric from asymmetric CMKs. It also provides information that is particularly important to asymmetric CMKs, such as the key usage (encryption or signing) and the encryption algorithms or signing algorithms that the CMK supports.  DescribeKey does not return the following information:   Aliases associated with the CMK. To get this information, use ListAliases.   Whether automatic key rotation is enabled on the CMK. To get this information, use GetKeyRotationStatus. Also, some key states prevent a CMK from being automatically rotated. For details, see How Automatic Key Rotation Works in AWS Key Management Service Developer Guide.   Tags on the CMK. To get this information, use ListResourceTags.   Key policies and grants on the CMK. To get this information, use GetKeyPolicy and ListGrants.   If you call the DescribeKey operation on a predefined AWS alias, that is, an AWS alias with no key ID, AWS KMS creates an AWS managed CMK. Then, it associates the alias with the new CMK, and returns the KeyId and Arn of the new CMK in the response.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:DescribeKey (key policy)  Related operations:     GetKeyPolicy     GetKeyRotationStatus     ListAliases     ListGrants     ListKeys     ListResourceTags     ListRetirableGrants

    Args:
        key_id(str): Describes the specified customer master key (CMK).  If you specify a predefined AWS alias (an AWS alias with no key ID), KMS associates the alias with an AWS managed CMK and returns its KeyId and Arn in the response. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.init.describe(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.init.describe key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="describe_key",
        op_kwargs={"KeyId": key_id, "GrantTokens": grant_tokens},
    )


async def disable(hub, ctx, key_id: str) -> None:
    r"""
    **Autogenerated function**

    Sets the state of a customer master key (CMK) to disabled. This change temporarily prevents use of the CMK for cryptographic operations.  For more information about how key state affects the use of a CMK, see Key state: Effect on your CMK in the  AWS Key Management Service Developer Guide . The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:DisableKey (key policy)  Related operations: EnableKey

    Args:
        key_id(str): Identifies the customer master key (CMK) to disable. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.init.disable(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.init.disable key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="kms", operation="disable_key", op_kwargs={"KeyId": key_id}
    )


async def enable(hub, ctx, key_id: str) -> None:
    r"""
    **Autogenerated function**

    Sets the key state of a customer master key (CMK) to enabled. This allows you to use the CMK for cryptographic operations.  The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:EnableKey (key policy)  Related operations: DisableKey

    Args:
        key_id(str): Identifies the customer master key (CMK) to enable. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.init.enable(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.init.enable key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="kms", operation="enable_key", op_kwargs={"KeyId": key_id}
    )


async def replicate(
    hub,
    ctx,
    key_id: str,
    replica_region: str,
    policy: str = None,
    bypass_policy_lockout_safety_check: bool = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Replicates a multi-Region key into the specified Region. This operation creates a multi-Region replica key based on a multi-Region primary key in a different Region of the same AWS partition. You can create multiple replicas of a primary key, but each must be in a different Region. To create a multi-Region primary key, use the CreateKey operation. This operation supports multi-Region keys, an AWS KMS feature that lets you create multiple interoperable CMKs in different AWS Regions. Because these CMKs have the same key ID, key material, and other metadata, you can use them to encrypt data in one AWS Region and decrypt it in a different AWS Region without making a cross-Region call or exposing the plaintext data. For more information about multi-Region keys, see Using multi-Region keys in the AWS Key Management Service Developer Guide. A replica key is a fully-functional CMK that can be used independently of its primary and peer replica keys. A primary key and its replica keys share properties that make them interoperable. They have the same key ID and key material. They also have the same key spec, key usage, key material origin, and automatic key rotation status. AWS KMS automatically synchronizes these shared properties among related multi-Region keys. All other properties of a replica key can differ, including its key policy, tags, aliases, and key state. AWS KMS pricing and quotas for CMKs apply to each primary key and replica key. When this operation completes, the new replica key has a transient key state of Creating. This key state changes to Enabled (or PendingImport) after a few seconds when the process of creating the new replica key is complete. While the key state is Creating, you can manage key, but you cannot yet use it in cryptographic operations. If you are creating and using the replica key programmatically, retry on KMSInvalidStateException or call DescribeKey to check its KeyState value before using it. For details about the Creating key state, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide. The AWS CloudTrail log of a ReplicateKey operation records a ReplicateKey operation in the primary key's Region and a CreateKey operation in the replica key's Region. If you replicate a multi-Region primary key with imported key material, the replica key is created with no key material. You must import the same key material that you imported into the primary key. For details, see Importing key material into multi-Region keys in the AWS Key Management Service Developer Guide. To convert a replica key to a primary key, use the UpdatePrimaryRegion operation.   ReplicateKey uses different default values for the KeyPolicy and Tags parameters than those used in the AWS KMS console. For details, see the parameter descriptions.   Cross-account use: No. You cannot use this operation to create a CMK in a different AWS account.   Required permissions:     kms:ReplicateKey on the primary CMK (in the primary CMK's Region). Include this permission in the primary CMK's key policy.    kms:CreateKey in an IAM policy in the replica Region.   To use the Tags parameter, kms:TagResource in an IAM policy in the replica Region.    Related operations     CreateKey     UpdatePrimaryRegion

    Args:
        key_id(str): Identifies the multi-Region primary key that is being replicated. To determine whether a CMK is a multi-Region primary key, use the DescribeKey operation to check the value of the MultiRegionKeyType property. Specify the key ID or key ARN of a multi-Region primary key. For example:   Key ID: mrk-1234abcd12ab34cd56ef1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/mrk-1234abcd12ab34cd56ef1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        replica_region(str): The Region ID of the AWS Region for this replica key.  Enter the Region ID, such as us-east-1 or ap-southeast-2. For a list of AWS Regions in which AWS KMS is supported, see AWS KMS service endpoints in the Amazon Web Services General Reference. The replica must be in a different AWS Region than its primary key and other replicas of that primary key, but in the same AWS partition. AWS KMS must be available in the replica Region. If the Region is not enabled by default, the AWS account must be enabled in the Region.  For information about AWS partitions, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. For information about enabling and disabling Regions, see Enabling a Region and Disabling a Region in the Amazon Web Services General Reference.
        policy(str, optional): The key policy to attach to the CMK. This parameter is optional. If you do not provide a key policy, AWS KMS attaches the default key policy to the CMK. The key policy is not a shared property of multi-Region keys. You can specify the same key policy or a different key policy for each key in a set of related multi-Region keys. AWS KMS does not synchronize this property. If you provide a key policy, it must meet the following criteria:   If you don't set BypassPolicyLockoutSafetyCheck to true, the key policy must give the caller kms:PutKeyPolicy permission on the replica CMK. This reduces the risk that the CMK becomes unmanageable. For more information, refer to the scenario in the Default Key Policy section of the  AWS Key Management Service Developer Guide .   Each statement in the key policy must contain one or more principals. The principals in the key policy must exist and be visible to AWS KMS. When you create a new AWS principal (for example, an IAM user or role), you might need to enforce a delay before including the new principal in a key policy because the new principal might not be immediately visible to AWS KMS. For more information, see Changes that I make are not always immediately visible in the AWS Identity and Access Management User Guide.   The key policy size quota is 32 kilobytes (32768 bytes).  . Defaults to None.
        bypass_policy_lockout_safety_check(bool, optional): A flag to indicate whether to bypass the key policy lockout safety check.  Setting this value to true increases the risk that the CMK becomes unmanageable. Do not set this value to true indiscriminately. For more information, refer to the scenario in the Default Key Policy section in the AWS Key Management Service Developer Guide.  Use this parameter only when you intend to prevent the principal that is making the request from making a subsequent PutKeyPolicy request on the CMK. The default value is false. Defaults to None.
        description(str, optional): A description of the CMK. Use a description that helps you decide whether the CMK is appropriate for a task. The default value is an empty string (no description). The description is not a shared property of multi-Region keys. You can specify the same description or a different description for each key in a set of related multi-Region keys. AWS KMS does not synchronize this property. Defaults to None.
        tags(List, optional): Assigns one or more tags to the replica key. Use this parameter to tag the CMK when it is created. To tag an existing CMK, use the TagResource operation.  Tagging or untagging a CMK can allow or deny permission to the CMK. For details, see Using ABAC in AWS KMS in the AWS Key Management Service Developer Guide.  To use this parameter, you must have kms:TagResource permission in an IAM policy. Tags are not a shared property of multi-Region keys. You can specify the same tags or different tags for each key in a set of related multi-Region keys. AWS KMS does not synchronize this property. Each tag consists of a tag key and a tag value. Both the tag key and the tag value are required, but the tag value can be an empty (null) string. You cannot have more than one tag on a CMK with the same tag key. If you specify an existing tag key with a different tag value, AWS KMS replaces the current tag value with the specified one. When you assign tags to an AWS resource, AWS generates a cost allocation report with usage and costs aggregated by tags. Tags can also be used to control access to a CMK. For details, see Tagging Keys. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.init.replicate(ctx, key_id=value, replica_region=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.init.replicate key_id=value, replica_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="replicate_key",
        op_kwargs={
            "KeyId": key_id,
            "ReplicaRegion": replica_region,
            "Policy": policy,
            "BypassPolicyLockoutSafetyCheck": bypass_policy_lockout_safety_check,
            "Description": description,
            "Tags": tags,
        },
    )
